<?php
	/**
	 *	eBag
	 *
	 *	Open source company administration manager
	 *
	 *	@package	eBag
	 *	@author		Eper Kalman
	 *	@copyright	Copyright (c) 2012-2015, Eper Kalman
	 *	@license	GNU Affero General Public License Version 3 (http://www.gnu.org/licenses/agpl-3.0.html)
	 *	@since		Version 6.0.0
	 */

	/**
	 * eBag SQL class
	 */

	/**
	 * use the connection created by sessionhandler
	 * needs loaded basic helpers func is_empty
	 */

	class SQL	{

		var $RESULT;
		var $DISPLAY	=	FALSE;
		
		/**
		 * Connect
		 */
		
		function __construct()	{
		
			global $__CONF;
			
			$this->CHARS_FLAG = $__CONF->get('specialchars','flag');
			
			# connect
			
			$this->mysqli = new mysqli($__CONF->get('connection', 'host'), $__CONF->get('connection', 'user'), $__CONF->get('connection', 'password'));

			if ($this->mysqli->connect_error) exit('Can\'t connect to mysql server ('.$this->mysqli->connect_errno. ') '. $this->mysqli->connect_error.' !');
			
			$this->mysqli->set_charset("utf8");

			$this->mysqli->query(" SET NAMES 'utf8' COLLATE 'utf8_bin' ");
			
			$this->mysqli->query(" SET SESSION wait_timeout=28800, lock_wait_timeout=28800, sql_mode=(SELECT REPLACE(REPLACE(@@SESSION.sql_mode , 'STRICT_TRANS_TABLES', '' ), 'STRICT_ALL_TABLES', '')) ");
			
			# Important to be set separated (built in)

			$this->mysqli->query(' SET SESSION innodb_lock_wait_timeout=3600, innodb_strict_mode=OFF ');
		}

		/**
		 * Sets the connection resource
		 */

		public function conn($resource)	  {

			return;
		}

		/**
		 * Returns mysql version number
		 */

		public function server_version()	{

			return $this->mysqli->server_info;
		}

		/**
		 * Starts the transaction
		 */

		public function transaction()	{

			$this->mysqli->autocommit(FALSE);
		}


		/**
		 * Commits the transaction
		 */
		
		public function commit()	{

			$this->mysqli->commit();
		}


		/**
		 * Rollback
		 */

		public function rollback()	{

			$this->mysqli->rollback();
		}

		/**	
		 * retuns last insert id
		 */

		public function lastid()	{

			return $this->mysqli->insert_id;
		}

		/**
		 * returns affected rows
		 */
		 
		 public function affected_rows()	{
		 
		      return $this->mysqli->affected_rows;
		 }
		 
		/**
		 * Execute query
		 */

		public function query($query)	{

			if ($this->DISPLAY) echo $query;

			$this->RESULT	=	$this->mysqli->query($query);

			if ($this->RESULT===FALSE)	{

				$ERROR = $this->mysqli->error;

				$this->rollback();
				
				$this->mysqli->query('UNLOCK TABLES');
				
				trigger_error($ERROR, E_USER_ERROR);

				exit("Fatal SQL error :\r\n".$ERROR);
			}
		}

		/**
		 * Returns results SQL_CALC_FOUND_ROWS number of rows
		 */

		public function calc_rows()	{

			$COUNT = $this->mysqli->query('SELECT FOUND_ROWS()');

			$row = $COUNT->fetch_row();

			$COUNT->close();

			return $row[0];
		}

		/**
		 * Returns results number of rows
		 */

		public function num_rows()	{

			return $this->RESULT->num_rows;
		}


		/**
		 * Escapes $_POST-ed string to write into base
		 */

		public function escape($string)	{

			if (is_empty($string))	return 'NULL';

			return $this->mysqli->real_escape_string(htmlspecialchars($string, $this->CHARS_FLAG, 'UTF-8', FALSE));
		}

		/**
		 * Escapes string with null and quotes
		 */

		public function n_escape($string)	{

			$string	= $this->escape($string);

			if ($string != 'NULL') $string="'$string'";

			return $string;
		}


		/**
		 * Adds slashes to REGEXP special characters
		 */

		private function mb_ereg_quote($string)	{
		
			return mb_ereg_replace_callback('\\\\|\+|\*|\?|\[|\^|\]|\$|\(|\)|\{|\}|\=|\!|\<|\>|\||\:|\-|\~', function ($m) {return '\\'.$m[0];}, $string);
		}

		
		/**
		 * Escapes string to (REGEXP) searches
		 */

		public function s_escape($string, $brackets="WITHOUT_REGEXP_BRACKETS")	{
			
			if (is_empty($string)) return $string;
			
			if ($brackets=='REGEXP') $string = $this->mb_ereg_quote($string);

			return $this->escape($string);
		}


		/**
		 * Re-escape string readed from base to write back without quotes and NULL
		 */

		public function r_escape($string)	{

			if (is_empty($string)) return $string;

			return $this->mysqli->real_escape_string($string);
		}


		/**
		 * Re-scapes string readed from base to write back with null and quotes
		 */

		public function nr_escape($string)	{

			if (is_empty($string)) return 'NULL';

			return '\''.$this->mysqli->real_escape_string($string).'\'';
		}


		/**
		 * Frees the result
		 */

		public function free()	{

			$this->RESULT->close();
		}
	}

?>
