<?php
	/**
	 *	eBag
	 *
	 *	Open source company administration manager
	 *
	 *	@package	eBag
	 *	@author		Eper Kalman
	 *	@copyright	Copyright (c) 2012-2015, Eper Kalman
	 *	@license	GNU Affero General Public License Version 3 (http://www.gnu.org/licenses/agpl-3.0.html)
	 *	@since		Version 6.0.0
	 */

	/**
	 * eBag create real mysql connection for backup restoration
	 */
	 
	class SQLREAL		{
	
		var $RESULT;
	
		/**
		 * Connect
		 */
		
		function __construct()	  {

			global $__CONF;
			
			$this->CHARS_FLAG = $__CONF->get('specialchars','flag');
		
			$this->connected = FALSE;
		
			if ($this->mysqli = mysqli_init())	{
			
				if ($this->mysqli->options(MYSQLI_OPT_LOCAL_INFILE, TRUE))	{
			
					if ($this->mysqli->real_connect($__CONF->get('connection', 'host'), $__CONF->get('connection', 'user'), $__CONF->get('connection', 'password')))	{
					
						$this->connected = TRUE;
					
						$this->mysqli->set_charset("utf8");

						$this->mysqli->query(" SET NAMES 'utf8' COLLATE 'utf8_bin' ");
						
						$this->mysqli->query(" SET SESSION wait_timeout=28800, lock_wait_timeout=28800 ");
						
						$this->mysqli->query(" SET SESSION innodb_lock_wait_timeout=3600 ");
					}
				}
			}
		}
		
		/**
		 * Returns true if the connection is established
		 */
		
		public function connected()	{
		
			return $this->connected;
		}
		
		/**
		 * Returns mysql version number
		 */

		public function server_version()	{

			return $this->mysqli->server_info;
		}

		/**
		 * Starts the transaction
		 */

		public function transaction()	{

			$this->mysqli->autocommit(FALSE);
		}
		
		/**
		 * Commits the transaction
		 */
		
		public function commit()	{

			$this->mysqli->commit();
		}

		/**
		 * Rollback
		 */

		public function rollback()	{

			$this->mysqli->rollback();
		}
		
		/**
		 * Execute query
		 */

		public function query($query)	{
		
			$this->RESULT =	$this->mysqli->query($query);

			if ($this->RESULT===FALSE)	{

				$ERROR = $this->mysqli->error;

				$this->rollback();
				
				$this->mysqli->query('UNLOCK TABLES');
				
				trigger_error($ERROR, E_USER_ERROR);

				exit("Fatal SQL error :\r\n".$ERROR);
			}
		}
	
		/**
		 * Returns results number of rows
		 */

		public function num_rows()	{

			return $this->RESULT->num_rows;
		}
		
		/**
		 * Escapes $_POST-ed string to write into base
		 */

		public function escape($string)	{

			if (is_empty($string))	return 'NULL';

			return $this->mysqli->real_escape_string(htmlspecialchars($string, $this->CHARS_FLAG, 'UTF-8', FALSE));
		}
		
		/**
		 * Re-escape string readed from base to write back without quotes and NULL
		 */

		public function r_escape($string)	{

			if (is_empty($string)) return $string;

			return $this->mysqli->real_escape_string($string);
		}
		
		/**
		 * Closes the connection
		 */

		function __destruct()	{
		
			$this->mysqli->close();
		}
	}
?>