<?php
	/**
	 *	eBag
	 *
	 *	Open source company administration manager
	 *
	 *	@package	eBag
	 *	@author		Eper Kalman
	 *	@copyright	Copyright (c) 2012-2015, Eper Kalman
	 *	@license	GNU Affero General Public License Version 3 (http://www.gnu.org/licenses/agpl-3.0.html)
	 *	@since		Version 6.0.0
	 */

	/**
	 *	eBag databases installation (stand alone or via ajax call)
	 */
	 
	# check for installed mark, prevent executing after install
	 
	if (is_file('../conf/installed.conf'))	{
	 
		include('../views/logout.php'); 
		  
		exit;
	}

	define ('BASEDIR', '../');
	
	# set time limit to zero for any case
	
	set_time_limit(0);

	# read the configuration

	require_once(BASEDIR.'classes/INIload.class.php');

	$__CONF		=	new INI_load(BASEDIR.'conf/eBag.ini', TRUE);

	# start errorhandler

	require_once (BASEDIR.'classes/Errorhandler.class.php');

	$__HANDLER	=	new ERRHANDLER();
	$__HANDLER	->	start();

	# Load the language
	
	require_once (BASEDIR.'classes/Language.class.php');
	
	$lang 	= strtolower($__CONF->get('language', 'lang'));

	$__LANG	= new Lang(BASEDIR."lang/$lang/language.$lang", 0, TRUE);

	# Starting installation

	class Create	{

		var $mysqli	=	FALSE;
		var $QUERY	=	FALSE;
		var $result	=	FALSE;

		# Create new connection

		function __construct()	{

			global $__CONF;

			$this->CONF	=	&$__CONF;

			$this->mysqli = new mysqli($this->CONF->get('connection', 'host'), $this->CONF->get('connection', 'user'), $this->CONF->get('connection', 'password'));

			if ($this->mysqli->connect_error)	{

				$this->error('Can\'t connect to mysql server ('.$this->mysqli->connect_errno. ') '. $this->mysqli->connect_error.' !');
			}
			
			$this->mysqli->set_charset("utf8");

			$this->mysqli->query("SET NAMES 'utf8' COLLATE 'utf8_bin'");
		}

		# Create new base

		public function create_base($NAME)	{

			$this->QUERY="CREATE DATABASE IF NOT EXISTS `$NAME` DEFAULT CHARACTER SET utf8 COLLATE utf8_bin";
			
			$this->query();
		}

		# Drop base

		public function drop_base($NAME)	{

			$this->QUERY="DROP DATABASE IF EXISTS `$NAME`";

			$this->query();
		}

		# Create new table
		 
		public function create_table($NAME, $SYNTAX)	{

			$this->QUERY="CREATE TABLE IF NOT EXISTS $NAME $SYNTAX";

			$this->query();
		}

		# Drop table

		public function drop_table($NAME)	{

			$this->QUERY="DROP TABLE IF EXISTS $NAME";

			$this->query();
		} 

		# verify that base exists

		public function year_exists()	{

			$year = date("Y");

			$this->query("	SELECT SCHEMA_NAME FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME = 'ebagdata$year'	");

			if ($this->result->num_rows) return TRUE;

			return FALSE;
		}
		
		# escape

		public function escape($string)	{

			return $this->mysqli->real_escape_string(htmlspecialchars($string, $this->CONF->get('specialchars', 'flag'), 'UTF-8', FALSE));
		}

		# Execute query

		public function query($QUERY=FALSE)	{

			if ($QUERY) $this->QUERY=$QUERY;

			$this->result = $this->mysqli->query($this->QUERY);

			if ($this->result===FALSE)	{

				echo	"Error executing query $this->QUERY !<br>\n"
				 	.'Mysql reports:'.$this->mysqli->error;
				exit;
			}
		}
	}

	# verify permissions for temporary and upload folder

	if ((! is_writable(BASEDIR.'tmp')) or (! is_writable(BASEDIR.'uploads'))) exit($__LANG->get('dirspermissiondenied'));
	
	# Create bases

	$new	=	new Create();

	# verify base existens

	if ($new->year_exists())	{

		unset($new);

		exit($__LANG->get('baseinstalledonce'));
	}

	$BASE	=	'ebag';

	$new	->	create_base($BASE);

	# User logins
	
	$TABLE 	= 'users';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY	(`personID`),
	`surname` 	varchar(20) NOT NULL,
	`lastname` 	varchar(20) NOT NULL,
	`username` 	varchar(30) NOT NULL,
	`password` 	text NOT NULL,
	`mail` 		varchar(40),
	`permission` 	text NOT NULL,
	`deleted` 	boolean,
	 INDEX		(`username`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	// insert first user: root

	require_once(BASEDIR.'helpers/basichelpers.php');

	$permission = '/addressbook=2/discounts=2/services=2/feedstock=2/operating_suplies=2/stock=2/service_lists=2/offers=2/orders=2/production=2/deliverys=2/bills=2/payments=2/summ_for_customer=2/employees=2/salarys=2/settings=2/users=2';
	
	$password = $new->mysqli->real_escape_string(md5('root'));
	
	$new	->	query("INSERT INTO $BASE.$TABLE VALUES (NULL, 'Surname', 'Name', 'root', '$password', NULL, '$permission', '0')");
	
	unset($password);

	# Company data

	$TABLE	= 'companydata';

	$SYNTAX	= '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`companyname` varchar(40) NOT NULL,
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`telephone1` varchar(30),
	`telephone2` varchar(30),
	`fax` varchar(30),
	`mail` varchar(40),
	`website` varchar(40),
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`tax_id_number` varchar(30),	
	`registration_number` varchar(40),
	`company_number` varchar(40),
	`business_activity_code` varchar(40),
	`deleted` boolean
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# Settings

	$TABLE	= 'settings';
	$SYNTAX = '  
	(
	`key` 	varchar(40) NOT NULL,
	`value` text NOT NULL,
	 INDEX (`key`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# insert initial values
	
	$SALARY_CONS = array();
	
	$SALARY_CONS['overtime_work'] = $SALARY_CONS['night_work'] = $SALARY_CONS['holiday_work'] = $SALARY_CONS['sick_leave'] = $SALARY_CONS['annual_leave'] = $SALARY_CONS['holiday'] = 100;
	
	$SERIALIZED = $new->mysqli->real_escape_string(serialize($SALARY_CONS));
	
	$insert="INSERT INTO $BASE.$TABLE  VALUES ('discount', '0'),
						  ('salary_constants', '$SERIALIZED')	";
	
	$new->query($insert);

	unset($insert, $SALARY_CONS, $SERIALIZED);

	# units

	$TABLE = 'units';

	$SYNTAX = '  
	(
	`name` 	varchar(40) NOT NULL,
	`type` varchar(40),
	`default` boolean,
	 INDEX (`name`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$PCS = $new->escape($__LANG->get('primary_unit_name'));

	$insert="INSERT INTO $BASE.$TABLE  VALUES	('$PCS', 'int', '1'), 
							('m', '', NULL),
							('mm', '', NULL),
							('Kg', '', NULL),
							('g', '', NULL)	";

	$new->query($insert);

	unset($insert);

	# Payments

	$TABLE	= 'payments';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`description` 	varchar(40) NOT NULL,
	`expected_after_day` int NOT NULL,
	`default` boolean,
	 INDEX (`description`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# load the language file & write initial values

	require_once(BASEDIR.'classes/PAYMENTinstaller.class.php');
	
	$__PAYMENTS	=	new PAYMENTSINSTALLER(BASEDIR."lang/$lang/payments.$lang");

	$PAYMENTSNAMES	=	$__PAYMENTS->getnames();
	$PAYMENTSVALUES	=	$__PAYMENTS->getvalues();
	$DEFAULTPAYMENT	=	$__PAYMENTS->getdefault();

	unset ($__PAYMENTS);

	$COUNT	=	count($PAYMENTSNAMES);

	for ($i=0; $i<$COUNT; $i++)	{

		if ($PAYMENTSNAMES[$i] == $DEFAULTPAYMENT) {$DEFAULT = "'1'";} else {$DEFAULT = 'NULL';}

		$insert	= "INSERT INTO $BASE.$TABLE VALUES (NULL, '".$PAYMENTSNAMES[$i]."', '".$PAYMENTSVALUES[$i]."', $DEFAULT)";

		$new->query($insert);
	}
	
	unset($insert, $COUNT);

	# Deliverys

	$TABLE	= 'deliverys';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`type` 	varchar(40) NOT NULL,
	`default` boolean,
	 INDEX (`type`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# load the languga file & write initial values

	require_once(BASEDIR.'classes/DELIVERYinstaller.class.php');
	
	$__DELIVERYS		=	new DELIVERYSINSTALLER(BASEDIR."lang/$lang/deliverys.$lang");

	$DELIVERYTYPES		=	$__DELIVERYS->gettypes();

	$DEFAULTDELIVERY	=	$__DELIVERYS->getdefault();

	foreach ($DELIVERYTYPES as $TYPE)	{

		if ($TYPE == $DEFAULTDELIVERY) {$DEFAULT = "'1'";} else {$DEFAULT = 'NULL';}

		$insert	= "INSERT INTO $BASE.$TABLE VALUES (NULL, '$TYPE', $DEFAULT)";

		$new->query($insert);
	}

	unset($DEFAULTDELIVERY, $DELIVERYTYPES, $__DELIVERYS);

	# Production phases

	$TABLE	= 'production_phases';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`phase` varchar(40) NOT NULL,
	`default` boolean,
	 INDEX (`phase`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# insert default production phases defined in lang file productionphase0 (feedstock & finished)

	$PHASE1	= $new->escape($__LANG->get('productionphase0'));
	$PHASE2	= $new->escape($__LANG->get('finished'));

	$new->query("	INSERT INTO $BASE.$TABLE VALUES (NULL, '$PHASE1', '1')	");
	$new->query("	INSERT INTO $BASE.$TABLE VALUES (NULL, '$PHASE2', '0')	");

	unset($PHASE1, $PHASE2);

	# Evidented years

	$TABLE	= 'years';
	$SYNTAX = '  
	(
	`year` 	 varchar(30) NOT NULL,
	`closed` varchar(1),
	 INDEX (`year`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	// insert current year
	$year	=	date("Y");
	$new	->	query("INSERT INTO $BASE.$TABLE VALUES ('$year', NULL)");

	# Reminder

	$TABLE 	= 'reminder';
	$SYNTAX = '  
	(
	`user`	varchar(20) NOT NULL,
	`date`	DATE NOT NULL,
	`value`	text NOT NULL,
	 INDEX (`user`, `date`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# uploaded files

	# note: types p=>personal, c=>company

	$TABLE 	= 'uploads';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`type` varchar(2) NOT NULL,
	`owner` varchar(40) NOT NULL,
	`directoryID` int NOT NULL,
	`filename` text NOT NULL,
	`filesize` bigint NOT NULL,
	`mimetype` varchar(50) NOT NULL,
	`date_of_creation` date NOT NULL,
	 INDEX (`type`, `owner`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# Temporary base for sessions

	$BASE	=	'ebagtemp';

	$new	->	create_base($BASE);

	$TABLE 	= 'sessions';
	$SYNTAX = '
	(
	`SID` char(100) NOT NULL,
	`expiration` int(11) NOT NULL,
	`value` text NOT NULL,
	 PRIMARY KEY  (SID),
	 INDEX (`expiration`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE 	= 'loggeds';
	$SYNTAX = '  
	(
	`SID` char(100) NOT NULL,
	`user` int NOT NULL,
	 PRIMARY KEY  (`SID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);
	
	$TABLE = 'norestart';
	$SYNTAX = '
	(
	`true` int NOT NULL
	) engine=memory';
	
	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# eBag data Stocks base

	$BASE	=	'ebagstock';
	$new	->	create_base($BASE);

	# Global Stock (fininished goods & all articles)

	$TABLE	= 'finished_goods_stock';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`code` varchar(25) NOT NULL,
	`articalname` varchar(40) NOT NULL,
	`dimensions` varchar(40) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`quantity` decimal(14,2) NOT NULL,
	`quantity_ordered` decimal(14,2),
	`quantity_ordered_to_stock` decimal(14,2),
	`quantity_on_opened_order_to_stock` decimal(14,2),
	`quantity_in_production` decimal(14,2),
	`quantity_as_part` decimal(14,2),
	`price` decimal(12,2) NOT NULL,
	`tax` decimal(10,2) NOT NULL,
	`price_with_tax` decimal(12,2) NOT NULL,
	`purchase_price` decimal(12,2),
	`origin` varchar(30) NOT NULL,
	`supplier` varchar(40) NOT NULL,
	`supplierID` int NOT NULL,
	`comment` text,
	`deleted` boolean,
	 INDEX (`code`, `articalname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# Feedstock

	$TABLE	= 'feedstock';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`code` varchar(25) NOT NULL,
	`feedstockname` varchar(40) NOT NULL,
	`dimensions` varchar(40) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`quantity` decimal(14,2) NOT NULL,
	`quantity_ordered_to_stock` decimal(14,2),
	`quantity_in_production` decimal(14,2),
	`quantity_on_opened_order_to_stock` decimal(14,2),
	`purchase_price` decimal(12,2),
	`calculation_price` decimal(12,2),
	`origin` varchar(30) NOT NULL,
	`supplier` varchar(40) NOT NULL,
	`supplierID` int NOT NULL,
	`comment` text,
	`deleted` boolean,
	 INDEX(`code`, `feedstockname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# Operating supplies

	$TABLE	= 'operating_suplies';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`code` varchar(25) NOT NULL,
	`supliename` varchar(40) NOT NULL,
	`dimensions` varchar(40),
	`unit` varchar(10) NOT NULL,
	`quantity` decimal(14,2) NOT NULL,
	`quantity_in_production` decimal(14,2),
	`purchase_price` decimal(12,2) NOT NULL,
	`comment` text,
	`deleted` boolean,
	 INDEX(`code`, `supliename`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# Services list

	$TABLE	= 'services';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`code` varchar(25) NOT NULL,
	`servicename` varchar(40) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`price` decimal(12,2) NOT NULL,
	`tax` decimal(10,2) NOT NULL,
	`price_with_tax` decimal(12,2) NOT NULL,
	`comment` text,
	`deleted` boolean,
	 INDEX(`code`, `servicename`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# Feedstock requests for services (list connected to services stock)

	$TABLE	= 'feedstock_requests_list';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`serviceID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`feedstockname` varchar(40) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`deleted` boolean,
	 INDEX(`serviceID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# eBag Data Base

	$BASE	=	'ebagdata'.$year;

	$new	->	create_base($BASE);
 
	# Address Book

	$TABLE	= 'addressbook';

	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`contactname` varchar(40) NOT NULL,
	`contactperson` varchar(30),
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`telephone1` varchar(30),
	`telephone2` varchar(30),
	`fax` varchar(30),
	`mobilephone` varchar(30),
	`mail` varchar(40),
	`website` varchar(40),
	`contacttype` int NOT NULL,
	`delivery_country` varchar(30),
	`delivery_city` varchar(30),
	`delivery_street` varchar(30),
	`delivery_zip` varchar(30),
	`delivery_day_of_week` int NOT NULL,
	`critic` varchar(2) NOT NULL,
	`article_discount` decimal(10,2),
	`service_discount` decimal(10,2),
	`seller` int NOT NULL,
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`tax_id_number` varchar(40),
	`deleted` boolean,
	 INDEX(`contactname`, `city`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# enters are the same for all

	$TABLE	= 'finished_goods_stock_enter';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`delivery_list_number` varchar(40),
	`bill_number` varchar(40),
	`order_to_stockID` int,
	`code` varchar(25) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`date` DATE NOT NULL,
	`username` varchar(20) NOT NULL,
	`deleted` boolean,
	 INDEX(`delivery_list_number`, `bill_number`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'feedstock_enter';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'operating_suplies_enter';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'inventory_header';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`stock` varchar(40) NOT NULL,
	`date_of_creation` date NOT NULL,
	`employeeID` int NOT NULL,
	`user` varchar(20) NOT NULL,
	`comment` text,
	`deleted` boolean,
	INDEX(`stock`, `date_of_creation`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'inventory_data';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`inventoryID` int NOT NULL,
	`stockID` int NOT NULL,
	`quantity_before` decimal(14,2) NOT NULL,
	`quantity_after` decimal(14,2) NOT NULL,
	`deleted` boolean,
	INDEX(`inventoryID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# services list (2 tables: header and data)

	$TABLE	= 'services_header';

	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`companyID` int NOT NULL, 
	`contactID` bigint NOT NULL, 
	`contactname` varchar(40) NOT NULL,
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`delivery_country` varchar(30),
	`delivery_city` varchar(30),
	`delivery_street` varchar(30),
	`delivery_zip` varchar(30),
	`service_discount` decimal(10,2),
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`contacttype` varchar(30),
	`seller` varchar(30) NOT NULL,
	`date_of_creation` DATE NOT NULL,
	`date_of_deadline` DATE NOT NULL,
	`payment_form` int NOT NULL,
	`delivery_day_of_week` int NOT NULL,
	`finished` int NOT NULL,
	`date_of_finishing` DATE,
	`finisher` varchar(40),
	`billed` int NOT NULL,
	`billID` varchar(15),
	`comment` text,
	`annotation` text,
	`currency` varchar(15) NOT NULL,
	`valuta` varchar(15) NOT NULL,
	`exchange_rate` decimal(10,2) NOT NULL,
	`session_discount` decimal(10,2) NOT NULL,
	`use_session_discount` varchar(2),
	`use_service_discount` varchar(2),
	`delete_reason` varchar(30),
	`deleted` boolean,
	 INDEX (`contactID`, `contactname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'services_data';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`reversID` varchar(15) NOT NULL,
	`code` varchar(25) NOT NULL,
	`servicename` varchar(40) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`price` decimal(12,2) NOT NULL,
	`tax` decimal(10,2) NOT NULL,
	`finished` boolean,
	`deleted` boolean,
	 INDEX(`reversID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'offers_header';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`companyID` int NOT NULL, 
	`contactID` bigint NOT NULL, 
	`contactname` varchar(40) NOT NULL,
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`delivery_country` varchar(30),
	`delivery_city` varchar(30),
	`delivery_street` varchar(30),
	`delivery_zip` varchar(30),
	`service_discount` decimal(10,2),
	`article_discount` decimal(10,2),
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`deadline_days` int NOT NULL,
	`delivery_day_of_week` varchar(30) NOT NULL,
	`contacttype` varchar(30) NOT NULL,
	`seller` varchar(30) NOT NULL,
	`ordered` varchar(2) NOT NULL,
	`orderID` int,
	`comment` text,
	`annotation` text,
	`currency` varchar(15) NOT NULL,
	`valuta` varchar(15) NOT NULL,
	`exchange_rate` decimal(10,2) NOT NULL,
	`session_discount` decimal(10,2) NOT NULL,
	`use_session_discount` varchar(2),
	`use_service_discount` varchar(2),
	`use_article_discount` varchar(2),
	`offer_in_valuta` varchar(2),
	`delivery_form` varchar (30),
	`payment_form` varchar (30),
	`date_of_creation` date NOT NULL,
	`delete_reason` varchar(30),
	`deleted` boolean,
	 INDEX(`contactID`, `contactname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# note: column type stores offered code is service or artical
	
	$TABLE	= 'offers_data';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`offerID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`name` varchar(40) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`price` decimal(12,2) NOT NULL,
	`tax` decimal(10,2) NOT NULL,	
	`type` varchar(1) NOT NULL,
	`deleted` boolean,
	 INDEX(`offerID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'orders_header';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`companyID` int NOT NULL, 
	`contactID` bigint NOT NULL,
	`contactname` varchar(40) NOT NULL,
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`delivery_country` varchar(30),
	`delivery_city` varchar(30),
	`delivery_street` varchar(30),
	`delivery_zip` varchar(30),
	`article_discount` decimal(10,2),
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`delivery_day_of_week` varchar(30) NOT NULL,
	`contacttype` varchar(30) NOT NULL,
	`seller` varchar(30) NOT NULL,
	`comment` text,
	`annotation` text,
	`currency` varchar(15) NOT NULL,
	`valuta` varchar(15) NOT NULL,
	`exchange_rate` decimal(10,2) NOT NULL,
	`session_discount` decimal(10,2) NOT NULL,
	`use_session_discount` varchar(2),
	`use_article_discount` varchar(2),
	`delivery_form` varchar (30),
	`payment_form` varchar (30),
	`connected_with_offer` int,
	`date_of_creation` date NOT NULL,
	`date_of_deadline` date NOT NULL,
	`delivered` varchar(5) NOT NULL,
	`delete_reason` varchar(30),
	`deleted` boolean,
	 INDEX(`contactID`, `contactname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'orders_data';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`orderID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`articalname` varchar(40) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`price` decimal(12,2) NOT NULL,
	`tax` decimal(10,2) NOT NULL,	
	`deliverylistID` int,
	`productionorderID` int,
	`date_of_delivery` date,
	`deleted` boolean,
	 INDEX(`orderID`, `productionorderID`, `date_of_delivery`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'production_orders_header';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`stocktype` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`articalname` varchar(40) NOT NULL,
	`contactname` varchar(40) NOT NULL,
	`orderID` int NOT NULL,
	`date_of_creation` date NOT NULL,
	`date_of_deadline` date NOT NULL,
	`finished` varchar(2) NOT NULL,
	`date_of_finishing` date,
	`quantity` decimal(11,2) NOT NULL,
	`defective_quantity` decimal(11,2) NOT NULL,
	`drawingID` varchar(40),
	`technology` text,
	`production_phase` varchar(40),
	`delete_reason` varchar(30),
	`deleted` boolean,
	 INDEX(`orderID`, `contactname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'production_orders_data';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`productionorderID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`name` varchar(40) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`type` varchar(1)  NOT NULL,
	`deleted` boolean,
	 INDEX(`productionorderID`)
	) engine=innodb';
	
	# type : f -> feedstock
	#	 a -> artical (used as part)

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'production_orders_phases';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`productionorderID` int NOT NULL,
	`production_phase` varchar(40) NOT NULL,
	`finisher` varchar(40),
	`date` date,
	`process_time` int,
	 INDEX(`productionorderID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'orders_to_stock_header';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`companyID` int NOT NULL,
	`supplierID` bigint NOT NULL,
	`contactname` varchar(40) NOT NULL,
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`comment` text,
	`currency` varchar(15) NOT NULL,
	`exchange_rate` decimal(10,2) NOT NULL,
	`connected_with_orders` text,
	`ordered` varchar(2),
	`delivered` varchar(5),
	`date_of_order` date,
	`delete_reason` varchar(30),
	`deleted` boolean,
	 INDEX(`supplierID`, `contactname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# note: type storest information about from which stock is item 
	#	(a=>finished_goods_stock, f=>feedstock)

	$TABLE	= 'orders_to_stock_data';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`order2stockID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`name` varchar(40) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`price` decimal(12,2) NOT NULL,
	`date_of_delivery` date,
	`delivery_list_number` varchar(30),
	`bill_number` varchar(30),
	`ordered` varchar(2),
	`type`	varchar(2) NOT NULL,
	`deleted` boolean,
	 INDEX(`order2stockID`, `date_of_delivery`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'deliverys_header';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`companyID` int NOT NULL,
	`contactID` bigint NOT NULL,
	`contactname` varchar(40) NOT NULL,
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`delivery_day_of_week` varchar(30) NOT NULL,
	`contacttype` varchar(30) NOT NULL,
	`seller` varchar(30) NOT NULL,
	`comment` text,
	`annotation` text,
	`currency` varchar(15) NOT NULL,
	`delivery_form` varchar (30),
	`payment_form` varchar (30),
	`connected_with_orders` text,
	`billed` varchar (2) NOT NULL,
	`billID` int,
	`date_of_creation` date NOT NULL,
	`delete_reason` varchar(30),
	`deleted` boolean,
	 INDEX(`contactID`, `contactname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'deliverys_data';
	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`deliveryID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`name` varchar(40) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`price` decimal(14,2) NOT NULL,
	`tax` decimal(10,2) NOT NULL,	
	`datapersonID` int,
	`deleted` boolean,
	 INDEX(`deliveryID`, `datapersonID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'bills_header';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`companyID` int NOT NULL,
	`contactID` bigint NOT NULL,
	`contactname` varchar(40) NOT NULL,
	`country` varchar(30),
	`city` varchar(30) NOT NULL,
	`zip` varchar(30),
	`street` varchar(30) NOT NULL,
	`account1` varchar(40),
	`bank1` varchar(40),
	`account2` varchar(40),
	`bank2` varchar(40),
	`contacttype` varchar(30) NOT NULL,
	`currency` varchar(15) NOT NULL,
	`payment_form` varchar (30),
	`connected_with_deliverys` text,
	`connected_with_reverses` text,
	`date_of_creation` date NOT NULL,
	`payment_deadline` date NOT NULL,
	`comment` text,
	`annotation` text,
	`delete_reason` varchar(30),
	`deleted` boolean,
	 INDEX(`contactID`, `contactname`)
	) engine=innodb';
	
	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);
	
	$TABLE	= 'bills_data';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`billID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`name` varchar(40) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`price` decimal(14,2) NOT NULL,
	`tax` decimal(10,2) NOT NULL,	
	`dataID` int NOT NULL,
	`datatype` varchar(40) NOT NULL,
	`deleted` boolean,
	 INDEX(`billID`, `dataID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	# note: paymenst deleting is permanently
	#	deleted column needs by readers

	$TABLE	= 'claims';
	$SYNTAX = '  
	(
	`personID` bigint NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`billID` int NOT NULL,
	`date_of_creation` date NOT NULL,
	`payment_deadline` date NOT NULL,
	`contactID` bigint NOT NULL,
	`contactname` varchar(40) NOT NULL,
	`city` varchar(30) NOT NULL,
	`sum` decimal(14,2) NOT NULL,
	`baseyear` int NOT NULL,
	`deleted` boolean,
	 INDEX(`billID`, `baseyear`, `contactname`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'customers_payments';
	$SYNTAX = '
	(
	`personID` bigint NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`contactID` bigint NOT NULL,
	`contactname` varchar(40) NOT NULL,
	`city` varchar(30) NOT NULL,
	`paymentID` varchar(40),
	`date` date NOT NULL,
	`sum` decimal(14,2) NOT NULL,
	`bank` varchar(40),
	`account` varchar(40),
	`comment` varchar(40),
	`deleted` boolean,
	 INDEX(`contactID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'feedstock_requests';

	$SYNTAX = '
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`requestID` int NOT NULL,
	`reversID` int NOT NULL,
	`servicedataID` int NOT NULL,
	`date_of_creation` date NOT NULL,
	`code` varchar(25) NOT NULL,
	`feedstockname` varchar(40) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`delete_reason` text,
	`deleted` boolean,
	 INDEX(`requestID`,`reversID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE	= 'suplie_request_header';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),	
	`date_of_creation` DATE NOT NULL,
	`employeeID` int NOT NULL, 
	`user` varchar(20) NOT NULL,
	`comment` text,
	`deleted` boolean,
	 INDEX(`date_of_creation`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);
	
	$TABLE	= 'suplie_request_data';
	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`requestID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`name` varchar(40) NOT NULL,
	`quantity` decimal(11,2) NOT NULL,
	`unit` varchar(10) NOT NULL,
	`deleted` boolean,
	 INDEX(`requestID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE 	= 'employees';

	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`employeename` varchar(30) NOT NULL,
	`identity_number` varchar(25) NOT NULL,
	`profession` varchar(30) NOT NULL,
	`workplace` varchar(30) NOT NULL,
	`education_degree` varchar(30),
	`date_of_employment` DATE NOT NULL, 
	`city` varchar(30),
	`zip` varchar(30),
	`street` varchar(30),
	`telephone` varchar(30),
	`deleted` boolean
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE 	= 'working_hours';

	$SYNTAX = '  
	(
	`personID` int NOT NULL AUTO_INCREMENT, 
	 PRIMARY KEY(`personID`),
	`employeeID` INT NOT NULL,
	`employeename` varchar(30) NOT NULL,
	`date` date NOT NULL,
	`work_hours` decimal(10,2),
	`overtime_work_hours` decimal(10,2),
	`night_work` varchar(2),
	`night_overtime_work` varchar(2),
	`holiday_work` varchar(2),
	`sick_leave` varchar(2),
	`sick_leave_100` varchar(2),
	`annual_leave` varchar(2),
	`holiday` varchar(2),
	`deleted` boolean,
	 INDEX(`employeeID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE 	= 'salarys_personal_data';
	$SYNTAX = '  
	(
	`employeeID` int NOT NULL,
	 PRIMARY KEY(`employeeID`),
	`value` text NOT NULL
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE 	= 'employees_items_bonuses';
	$SYNTAX = '
	(
	`personID` bigint NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`employeeID` int NOT NULL,
	`stock_type` int NOT NULL,
	`stockID` int NOT NULL,
	`code` varchar(25) NOT NULL,
	`percent_production` decimal(10,2),
	`fix_production` decimal(10,2),
	`percent_services` decimal(10,2),
	`fix_services` decimal(10,2),
	`percent_product_sell` decimal(10,2),
	`fix_product_sell` decimal(10,2),
	`percent_service_sell` decimal(10,2),
	`fix_service_sell` decimal(10,2),
	`userID` int NOT NULL,
	`deleted` boolean,
	 INDEX(`employeeID`, `stock_type`, `stockID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);

	$TABLE 	= 'employees_phases_bonuses';
	$SYNTAX = '
	(
	`personID` bigint NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`employeeID` int NOT NULL,
	`setting_type`int NOT NULL,
	`stockID` int,
	`code` varchar(25),
	`phaseID` int NOT NULL,
	`production_phase` varchar(40) NOT NULL,
	`percent_phases` decimal(10,2),
	`fix_phases` decimal(10,2),
	`userID` int NOT NULL,
	`deleted` boolean,
	 INDEX(`employeeID`, `setting_type`, `phaseID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);
	
	# note bonus_to_ fields : 0 => none; 1 => for all; 2 => separated by codes
	
	$TABLE	= 'salarys';

	$SYNTAX = '  
	(
	`personID` bigint NOT NULL AUTO_INCREMENT,
	 PRIMARY KEY(`personID`),
	`companyID` int NOT NULL,
	`employeeID` int NOT NULL,
	`employeename` varchar(30) NOT NULL,
	`currency` varchar(30) NOT NULL,
	`salary_globals` text,		
	`fix_payment` decimal(10,2),
	`working_hour_value` decimal(10,2),
	`bonus_config` text,
	`additionals` text,
	`credits` text,
	`month` int NOT NULL,
	`month_part` int NOT NULL,
	`date_of_creation` date NOT NULL,
	`E_work` decimal(10,2) NOT NULL,
	`E_overtime_work` decimal(10,2) NOT NULL,
	`E_night_work` decimal(10,2) NOT NULL,
	`E_night_overtime_work` decimal(10,2) NOT NULL,
	`E_night_holiday_work` decimal(10,2) NOT NULL,
	`E_night_overtime_holiday_work` decimal(10,2) NOT NULL,
	`E_sick_leave` decimal(10,2) NOT NULL,
	`E_sick_leave_100` decimal(10,2) NOT NULL,
	`E_holiday_work` decimal(10,2) NOT NULL,
	`E_holiday_overtime_work` decimal(10,2) NOT NULL,
	`E_holiday` decimal(10,2) NOT NULL,
	`E_annual_leave` decimal(10,2) NOT NULL,
	`E_bonus_production` decimal(10,2) NOT NULL,
	`E_bonus_services` decimal(10,2) NOT NULL,
	`E_bonus_product_sell` decimal(10,2) NOT NULL,
	`E_bonus_service_sell` decimal(10,2) NOT NULL,
	`Salary_BASE` decimal(12,2) NOT NULL,
	`E_payment` decimal(12,2) NOT NULL,
	`comment` text,
	`annotation` text,
	`deleted` boolean,
	 INDEX(`employeeID`, `month`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);
	
	$TABLE	= 'salary_bonuses';

	$SYNTAX = '  
	(
	`salaryID` bigint NOT NULL,
	`employeeID` int NOT NULL,
	`bonus_to_production` text,
	`bonus_to_services` text,
	`bonus_to_product_sell` text,
	`bonus_to_service_sell` text,
	`deleted` boolean,
	 INDEX(`employeeID`, `salaryID`)
	) engine=innodb';

	$new	->	create_table($BASE.'.'.$TABLE, $SYNTAX);	
	
	
	file_put_contents('../conf/installed.conf', 'Deleting this file cause redirect to installation at starting eBag.');

	echo 'installed';
?>
