<?php
	/**
	 *	eBag
	 *
	 *	Open source company administration manager
	 *
	 *	@package	eBag
	 *	@author		Eper Kalman
	 *	@copyright	Copyright (c) 2012-2015, Eper Kalman
	 *	@license	GNU Affero General Public License Version 3 (http://www.gnu.org/licenses/agpl-3.0.html)
	 *	@since		Version 6.0.0
	 */

	/**	
	 * eBag order to stock change
	 */
	 
	if (! defined('eBag'))	{
	
	      include('../views/logout.php'); 
	      
	      exit();
	}

	load_f('is_real_positive');

	load_f('is_int_positive');

	class ORDER2STOCKCHANGE	{

		function __construct()	{

			global $__SQL, $__CONF;

			$this->SQL		=	&$__SQL;

			$this->BASE		=	$_SESSION['BASE'];

			$this->UNIT		=	new UNITloader($__CONF->get('cache', 'use_apc_cache'));

			$this->STOCKBASE	=	'ebagstock';
		}

		private function lock()		{

			$this->SQL->query("	LOCK TABLES 	$this->BASE.orders_to_stock_header WRITE, 
								$this->BASE.orders_to_stock_data WRITE,
								$this->STOCKBASE.finished_goods_stock WRITE, 
								$this->STOCKBASE.feedstock WRITE	");
		}

		private function unlock()	{

			$this->SQL->query('UNLOCK TABLES');
		}

		private function prepare($DATA)		{

			$PERSONIDS	=	$DATA['personID'];
			$QUANTITYS	=	$DATA['quantity'];
			$UNITS		=	$DATA['unit'];

			$LENGTH	=	count($PERSONIDS);

			if (! $LENGTH) return 'usererror';

			$RETURN	=	array();

			for ($i=0; $i<$LENGTH; $i++)	{
			
				if (! isset($RETURN['quantity'])) $RETURN['quantity'] = array();
				if (! isset($RETURN['personID'])) $RETURN['personID'] = array();

				$personID	=	$PERSONIDS[$i];
				$quantity	=	$QUANTITYS[$i];
				$unit		=	$UNITS[$i];

				# user input

				if ($this->UNIT->is_int_unit($unit))	{

					if (! is_int_positive($quantity)) $RETURN = 'usererror';
						
				}	else	 {

					if (! is_real_positive($quantity)) $RETURN = 'usererror';
				}

				if ($RETURN == 'usererror') break;

				$RETURN['quantity'][]	=	$quantity;
				$RETURN['personID'][]	=	$personID;
			}
	
			if ((is_array($RETURN)) && (! count($RETURN))) $RETURN = 'usererror';

			return $RETURN;
		}

		public function update($order2stockID, $DATA)	{

			# create array of deleted elements

			if (! $DATA['IDs']) return 'unknownerror';

			$order2stockID	=	$this->SQL->escape($order2stockID);

			$IDs	=	explode(',', $DATA['IDs']);

			if (! count($IDs)) return 'unknownerror';

			if ((! isset($DATA['personID'])) or (! count($DATA['personID'])))	{

				$DELETED	=	$IDs;

			}	else	  {

				$DELETED	=	array();

				foreach ($IDs as $personID)	{

					if (! in_array($personID, $DATA['personID'])) $DELETED[] = $personID;
				}
			}

			$this->SQL->transaction();
		
			$this->lock();

			# exist or not

			$this->SQL->query("	SELECT `ordered` 
						FROM $this->BASE.orders_to_stock_header 
						WHERE `personID`='$order2stockID' AND `deleted` IS NOT NULL LIMIT 1	");

			if (! $this->SQL->num_rows())	{

				$this->SQL->rollback();

				$this->unlock();

				return 'unexistentorder2stock';
			}

			$RESULT	=	$this->SQL->RESULT->fetch_row();

			if ($RESULT[0]) {$ORDERED = TRUE;} else {$ORDERED = FALSE;}

			# update comment in header

			$comment	=	$this->SQL->n_escape($DATA['comment']);

			$this->SQL->query("	UPDATE $this->BASE.orders_to_stock_header 
						SET `comment`=$comment 
						WHERE `personID`='$order2stockID' AND `deleted` IS NOT NULL LIMIT 1	");

			# prepare data (if deleted=ids every id is deleted, so there is nothing to do)
		
			if ($DELETED != $IDs)	{
			
				$DATA = $this->prepare($DATA);

				if (! isset($DATA['personID']))	$DATA = 'usererror';

				if (! is_array($DATA))	{

					$this->SQL->rollback();

					$this->unlock();

					return $DATA;
				}
			}

			$STOCKTABLES	=	array(	'a'	=>	'finished_goods_stock',
							'f'	=>	'feedstock'	);
			# do update

			if (($DELETED != $IDs) && ($LENGTH = count($DATA['personID'])))	{

				for ($i=0; $i<$LENGTH; $i++)	{

					$ID		=	$DATA['personID'][$i];
					$QUANTITY_NEW	=	$DATA['quantity'][$i];

					# note: if the item is delivered or deleted in meantime step over

					$this->SQL->query("	SELECT `code`, `quantity`, `type` 
								FROM $this->BASE.orders_to_stock_data
								WHERE `personID`='$ID' AND `date_of_delivery` IS NULL AND `deleted` IS NOT NULL LIMIT 1	");

					if (! $this->SQL->num_rows()) continue;

					$RESULT		=	$this->SQL->RESULT->fetch_assoc();

					$STOCKTABLE	=	$STOCKTABLES[$RESULT['type']];

					$code		=	$this->SQL->nr_escape($RESULT['code']);

					$quantity	=	$RESULT['quantity'];

					# update orders to stock data

					$this->SQL->query("	UPDATE $this->BASE.orders_to_stock_data 
								SET `quantity`='$QUANTITY_NEW' 
								WHERE `personID`='$ID' LIMIT 1	");

					# update stock

					if ($ORDERED)	{

						$this->SQL->query("	UPDATE $this->STOCKBASE.$STOCKTABLE 
									SET quantity_ordered_to_stock=quantity_ordered_to_stock-$quantity+$QUANTITY_NEW
							  		WHERE `code`=$code  AND `deleted` IS NOT NULL LIMIT 1	");

					}	else	 {

						$this->SQL->query("	UPDATE $this->STOCKBASE.$STOCKTABLE
									SET quantity_on_opened_order_to_stock=quantity_on_opened_order_to_stock-$quantity+$QUANTITY_NEW
									WHERE `code`=$code  AND `deleted` IS NOT NULL LIMIT 1	");
					}
				}
			}	

			# do delete

			if ($LENGTH = count($DELETED))	{

				foreach ($DELETED as $ID)	{

					# note: if the item is delivered or deleted in meantime step over

					$this->SQL->query("	SELECT `code`, `quantity`, `type` 
								FROM $this->BASE.orders_to_stock_data
								WHERE `personID`='$ID' AND `date_of_delivery` IS NULL AND `deleted` IS NOT NULL LIMIT 1	");

					if (! $this->SQL->num_rows()) continue;

					$RESULT		=	$this->SQL->RESULT->fetch_assoc();

					$STOCKTABLE	=	$STOCKTABLES[$RESULT['type']];

					$code		=	$this->SQL->nr_escape($RESULT['code']);

					$quantity	=	$RESULT['quantity'];

					# delete item from stock data

					$this->SQL->query("	UPDATE $this->BASE.orders_to_stock_data 
								SET `deleted`=NULL WHERE `personID`='$ID' LIMIT 1	");

					# update stock

					if ($ORDERED)	{

						$this->SQL->query("	UPDATE $this->STOCKBASE.$STOCKTABLE 
									SET quantity_ordered_to_stock=quantity_ordered_to_stock-$quantity
							  		WHERE `code`=$code  AND `deleted` IS NOT NULL LIMIT 1	");

					}	else	 {

						$this->SQL->query("	UPDATE $this->STOCKBASE.$STOCKTABLE
									SET quantity_on_opened_order_to_stock=quantity_on_opened_order_to_stock-$quantity
									WHERE `code`=$code  AND `deleted` IS NOT NULL LIMIT 1	");
					}
				}
			}

			# check maybe is everything deleted			
			
			$this->SQL->query("	SELECT `personID` 
						FROM $this->BASE.orders_to_stock_data 
						WHERE `order2stockID`='$order2stockID' AND `deleted` IS NOT NULL LIMIT 1	");

			if (! $this->SQL->num_rows())	{
			
				$SET_HEADER = ' `deleted`=NULL ';

			}	else	  {
			
				# check after change in which state is
				
				# states 0->not delivered; 1->delivered; 2->partially delivered
					
				$this->SQL->query("	SELECT `personID` 
							FROM $this->BASE.orders_to_stock_data 
							WHERE `order2stockID`='$order2stockID' AND `date_of_delivery` IS NULL AND `deleted` IS NOT NULL");
							
				if ($this->SQL->num_rows())	{
				
					$this->SQL->query("	SELECT `personID` 
								FROM $this->BASE.orders_to_stock_data 
								WHERE `order2stockID`='$order2stockID' AND `date_of_delivery` IS NOT NULL AND `deleted` IS NOT NULL ");
								
					if ($this->SQL->num_rows())	{$STATE = 2;} 	 else	{$STATE = 0;}
				
				}	else	  {
				
					$STATE = 1;
				}
				
				$SET_HEADER = " `delivered`='$STATE' ";
			}
			
			# update (or delete) header 

			$this->SQL->query("	UPDATE $this->BASE.orders_to_stock_header 
						SET $SET_HEADER
						WHERE `personID`='$order2stockID' LIMIT 1	");
						
			$this->SQL->commit();

			$this->unlock();

			return TRUE;
		}
	}

?>

