<?php
	/**
	 *	eBag
	 *
	 *	Open source company administration manager
	 *
	 *	@package	eBag
	 *	@author		Eper Kalman
	 *	@copyright	Copyright (c) 2012-2015, Eper Kalman
	 *	@license	GNU Affero General Public License Version 3 (http://www.gnu.org/licenses/agpl-3.0.html)
	 *	@since		Version 6.0.0
	 */

	/**
	 *	Check system before installation
	 *	Note: BASEDIR must be defined
	 */
	 
	if (! defined('eBag'))	{
	
	      include('../views/logout.php'); 
	      
	      exit();
	}
	 
	 class SystemCheck	{
	 
		var $required		=	array();
		var $recommended	=	array();
		
		function __construct()	{
		
			global $__LANG;
			
			$this->LANG = &$__LANG;
		
			$this->checkPhpVersion();
			
			$this->checkWritablefolders();
			
			$this->checkMBStringSupport();
			
			$this->checkMysqliSupport();
			
			$this->checkDirectives();
			
			$this->checkApcCache();
			
			$this->checkFsock();
			
			$this->checkConfAccess();
		}
		
		public function required()	{
		
			return (array)$this->required;
		}
		
		public function passed()	{
		
			$passed = TRUE;
		
			foreach ($this->required as $required)	{
			
				if (! $required[1]) {$passed = FALSE; break;}
			}
		
			return $passed;
		}
		
		public function recommended()	{
		
			return (array)$this->recommended;
		}
	
		private function checkPhpVersion()	{
		
			if (defined('PHP_VERSION')) {$version = PHP_VERSION;} else {$version = phpversion();}
			
			$passed = FALSE;
		
			if (version_compare($version, '5.2.3', '>=')) $passed = TRUE;
			
			$this->required[] = array($this->LANG['php_version'].' '.$version, $passed);
		}
		
		private function checkMysqliSupport()	{
		
			$passed = FALSE;
		
			if (class_exists('mysqli'))	$passed = TRUE;
			
			$this->required[] = array($this->LANG['database_support'], $passed);
		}
		
		private function checkMBStringSupport()	{
		
			$passed = FALSE;
		
			if ((function_exists('mb_strlen')) && (@ mb_strlen('test'))) $passed = TRUE;
			
			$this->required[] = array($this->LANG['mbstring_support'], $passed);
		}
		
		private function checkWritablefolders()	{
		
			$passed = FALSE;
			
			if ((is_writable(BASEDIR.'conf')) && (is_writable(BASEDIR.'conf/eBag.ini'))) $passed = TRUE;
			
			$this->required[] = array($this->LANG['conf_writable'], $passed);
			
			$passed = FALSE;
			
			if (is_writable(BASEDIR.'uploads')) $passed = TRUE;
			
			$this->required[] = array($this->LANG['upload_writable'], $passed);
			
			$passed = FALSE;
			
			if (is_writable(BASEDIR.'tmp')) $passed = TRUE;
			
			$this->required[] = array($this->LANG['temp_writable'], $passed);
		}
		
		private function checkDirectives()	{
		
			$passed = FALSE;
			
			if (!  ini_get('safe_mode')) $passed = TRUE;
			
			$this->required[] = array($this->LANG['safe_mode_is_off'], $passed);
			
			$passed = FALSE;
			
			if (! get_magic_quotes_runtime()) $passed = TRUE;
			
			$this->recommended[] = array($this->LANG['quotes_runtime_is_off'], $passed);
			
			$passed = FALSE;
			
			if (! get_magic_quotes_gpc()) $passed = TRUE;
			
			$this->recommended[] = array($this->LANG['quotes_gpc_is_off'], $passed);
		}
		
		private function checkApcCache()	{
		
			$passed = FALSE;
			
			if (	(function_exists('apc_store')) &&
				(@apc_store('test', 'test'))	)	$passed = TRUE;
				
			$this->recommended[] = array($this->LANG['apc_cache'], $passed);
		}
		
		private function checkFsock()	{
		
			$passed = FALSE;
			
			if (function_exists('fsockopen')) $passed = TRUE;
			
			$this->recommended[] = array($this->LANG['fsock_allowed'], $passed);
			
		}
		
		private function checkConfAccess()	{
		
			$passed = TRUE;

			if ((! isset($_SERVER['HTTP_HOST'])) or (stripos($_SERVER['HTTP_HOST'], '/') !== FALSE))	{
			
				if (isset($_SERVER['SERVER_NAME']) && $_SERVER['SERVER_NAME']) {$_SERVER['HTTP_HOST'] = $_SERVER['SERVER_NAME'];} else {$_SERVER['HTTP_HOST'] = 'localhost';}
			}
			
			load_f('php_self_path');
			
			$url = "http://{$_SERVER['HTTP_HOST']}".php_self_path().'/conf/eBag.ini';
			
			if (ini_get('allow_url_fopen'))	{
			
				if (@fopen($url, 'r')) $passed = FALSE;
				
			}	elseif (function_exists('fsockopen'))	  {
			
				$errno = $errstr = FALSE;
			
				$fp = @fsockopen($_SERVER['HTTP_HOST'], 80, $errno, $errstr, 30);
				
				if ($fp)	{
				
					fwrite($fp, "GET $url HTTP/1.1\r\n");
					fwrite($fp, "Host: {$_SERVER['HTTP_HOST']}\r\n");
					fwrite($fp, "Connection: Close\r\n\r\n");
					
					# RFC 2616 => Status-Line = HTTP-Version SP Status-Code SP Reason-Phrase CRLF
					
					if ($response = fgets($fp))	{
					
						$status = explode(' ', $response);
						
						if (((integer)$status[1]) == 200) $passed = FALSE;
					}

					fclose($fp);
				}
			
			}	else	{
			
				# unable to check
			
				$passed = NULL;
			}
		
			$this->recommended[] = array($this->LANG['preventing_conf_access'], $passed);
		}
	 }
	 
?>